from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepData import *
from OCC.Core.Interface import *
from OCC.Core.StepBasic import *
from OCC.Core.TCollection import *


class RWStepBasic_RWAction:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Action) -> None: ...
	def Share(self, ent: StepBasic_Action, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Action) -> None: ...

class RWStepBasic_RWActionAssignment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ActionAssignment) -> None: ...
	def Share(self, ent: StepBasic_ActionAssignment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ActionAssignment) -> None: ...

class RWStepBasic_RWActionMethod:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ActionMethod) -> None: ...
	def Share(self, ent: StepBasic_ActionMethod, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ActionMethod) -> None: ...

class RWStepBasic_RWActionRequestAssignment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ActionRequestAssignment) -> None: ...
	def Share(self, ent: StepBasic_ActionRequestAssignment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ActionRequestAssignment) -> None: ...

class RWStepBasic_RWActionRequestSolution:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ActionRequestSolution) -> None: ...
	def Share(self, ent: StepBasic_ActionRequestSolution, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ActionRequestSolution) -> None: ...

class RWStepBasic_RWAddress:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Address) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Address) -> None: ...

class RWStepBasic_RWApplicationContext:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ApplicationContext) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ApplicationContext) -> None: ...

class RWStepBasic_RWApplicationContextElement:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ApplicationContextElement) -> None: ...
	def Share(self, ent: StepBasic_ApplicationContextElement, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ApplicationContextElement) -> None: ...

class RWStepBasic_RWApplicationProtocolDefinition:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ApplicationProtocolDefinition) -> None: ...
	def Share(self, ent: StepBasic_ApplicationProtocolDefinition, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ApplicationProtocolDefinition) -> None: ...

class RWStepBasic_RWApproval:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Approval) -> None: ...
	def Share(self, ent: StepBasic_Approval, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Approval) -> None: ...

class RWStepBasic_RWApprovalDateTime:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ApprovalDateTime) -> None: ...
	def Share(self, ent: StepBasic_ApprovalDateTime, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ApprovalDateTime) -> None: ...

class RWStepBasic_RWApprovalPersonOrganization:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ApprovalPersonOrganization) -> None: ...
	def Share(self, ent: StepBasic_ApprovalPersonOrganization, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ApprovalPersonOrganization) -> None: ...

class RWStepBasic_RWApprovalRelationship:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ApprovalRelationship) -> None: ...
	def Share(self, ent: StepBasic_ApprovalRelationship, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ApprovalRelationship) -> None: ...

class RWStepBasic_RWApprovalRole:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ApprovalRole) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ApprovalRole) -> None: ...

class RWStepBasic_RWApprovalStatus:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ApprovalStatus) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ApprovalStatus) -> None: ...

class RWStepBasic_RWCalendarDate:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_CalendarDate) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_CalendarDate) -> None: ...

class RWStepBasic_RWCertification:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Certification) -> None: ...
	def Share(self, ent: StepBasic_Certification, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Certification) -> None: ...

class RWStepBasic_RWCertificationAssignment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_CertificationAssignment) -> None: ...
	def Share(self, ent: StepBasic_CertificationAssignment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_CertificationAssignment) -> None: ...

class RWStepBasic_RWCertificationType:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_CertificationType) -> None: ...
	def Share(self, ent: StepBasic_CertificationType, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_CertificationType) -> None: ...

class RWStepBasic_RWCharacterizedObject:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_CharacterizedObject) -> None: ...
	def Share(self, ent: StepBasic_CharacterizedObject, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_CharacterizedObject) -> None: ...

class RWStepBasic_RWContract:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Contract) -> None: ...
	def Share(self, ent: StepBasic_Contract, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Contract) -> None: ...

class RWStepBasic_RWContractAssignment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ContractAssignment) -> None: ...
	def Share(self, ent: StepBasic_ContractAssignment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ContractAssignment) -> None: ...

class RWStepBasic_RWContractType:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ContractType) -> None: ...
	def Share(self, ent: StepBasic_ContractType, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ContractType) -> None: ...

class RWStepBasic_RWConversionBasedUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ConversionBasedUnit) -> None: ...
	def Share(self, ent: StepBasic_ConversionBasedUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ConversionBasedUnit) -> None: ...

class RWStepBasic_RWConversionBasedUnitAndAreaUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ConversionBasedUnitAndAreaUnit) -> None: ...
	def Share(self, ent: StepBasic_ConversionBasedUnitAndAreaUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ConversionBasedUnitAndAreaUnit) -> None: ...

class RWStepBasic_RWConversionBasedUnitAndLengthUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ConversionBasedUnitAndLengthUnit) -> None: ...
	def Share(self, ent: StepBasic_ConversionBasedUnitAndLengthUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ConversionBasedUnitAndLengthUnit) -> None: ...

class RWStepBasic_RWConversionBasedUnitAndMassUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ConversionBasedUnitAndMassUnit) -> None: ...
	def Share(self, ent: StepBasic_ConversionBasedUnitAndMassUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ConversionBasedUnitAndMassUnit) -> None: ...

class RWStepBasic_RWConversionBasedUnitAndPlaneAngleUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ConversionBasedUnitAndPlaneAngleUnit) -> None: ...
	def Share(self, ent: StepBasic_ConversionBasedUnitAndPlaneAngleUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ConversionBasedUnitAndPlaneAngleUnit) -> None: ...

class RWStepBasic_RWConversionBasedUnitAndRatioUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ConversionBasedUnitAndRatioUnit) -> None: ...
	def Share(self, ent: StepBasic_ConversionBasedUnitAndRatioUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ConversionBasedUnitAndRatioUnit) -> None: ...

class RWStepBasic_RWConversionBasedUnitAndSolidAngleUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ConversionBasedUnitAndSolidAngleUnit) -> None: ...
	def Share(self, ent: StepBasic_ConversionBasedUnitAndSolidAngleUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ConversionBasedUnitAndSolidAngleUnit) -> None: ...

class RWStepBasic_RWConversionBasedUnitAndTimeUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ConversionBasedUnitAndTimeUnit) -> None: ...
	def Share(self, ent: StepBasic_ConversionBasedUnitAndTimeUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ConversionBasedUnitAndTimeUnit) -> None: ...

class RWStepBasic_RWConversionBasedUnitAndVolumeUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ConversionBasedUnitAndVolumeUnit) -> None: ...
	def Share(self, ent: StepBasic_ConversionBasedUnitAndVolumeUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ConversionBasedUnitAndVolumeUnit) -> None: ...

class RWStepBasic_RWCoordinatedUniversalTimeOffset:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_CoordinatedUniversalTimeOffset) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_CoordinatedUniversalTimeOffset) -> None: ...

class RWStepBasic_RWDate:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Date) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Date) -> None: ...

class RWStepBasic_RWDateAndTime:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DateAndTime) -> None: ...
	def Share(self, ent: StepBasic_DateAndTime, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DateAndTime) -> None: ...

class RWStepBasic_RWDateRole:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DateRole) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DateRole) -> None: ...

class RWStepBasic_RWDateTimeRole:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DateTimeRole) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DateTimeRole) -> None: ...

class RWStepBasic_RWDerivedUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DerivedUnit) -> None: ...
	def Share(self, ent: StepBasic_DerivedUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DerivedUnit) -> None: ...

class RWStepBasic_RWDerivedUnitElement:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DerivedUnitElement) -> None: ...
	def Share(self, ent: StepBasic_DerivedUnitElement, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DerivedUnitElement) -> None: ...

class RWStepBasic_RWDimensionalExponents:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DimensionalExponents) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DimensionalExponents) -> None: ...

class RWStepBasic_RWDocument:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Document) -> None: ...
	def Share(self, ent: StepBasic_Document, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Document) -> None: ...

class RWStepBasic_RWDocumentFile:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DocumentFile) -> None: ...
	def Share(self, ent: StepBasic_DocumentFile, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DocumentFile) -> None: ...

class RWStepBasic_RWDocumentProductAssociation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DocumentProductAssociation) -> None: ...
	def Share(self, ent: StepBasic_DocumentProductAssociation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DocumentProductAssociation) -> None: ...

class RWStepBasic_RWDocumentProductEquivalence:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DocumentProductEquivalence) -> None: ...
	def Share(self, ent: StepBasic_DocumentProductEquivalence, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DocumentProductEquivalence) -> None: ...

class RWStepBasic_RWDocumentRelationship:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DocumentRelationship) -> None: ...
	def Share(self, ent: StepBasic_DocumentRelationship, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DocumentRelationship) -> None: ...

class RWStepBasic_RWDocumentRepresentationType:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DocumentRepresentationType) -> None: ...
	def Share(self, ent: StepBasic_DocumentRepresentationType, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DocumentRepresentationType) -> None: ...

class RWStepBasic_RWDocumentType:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DocumentType) -> None: ...
	def Share(self, ent: StepBasic_DocumentType, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DocumentType) -> None: ...

class RWStepBasic_RWDocumentUsageConstraint:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_DocumentUsageConstraint) -> None: ...
	def Share(self, ent: StepBasic_DocumentUsageConstraint, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_DocumentUsageConstraint) -> None: ...

class RWStepBasic_RWEffectivity:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Effectivity) -> None: ...
	def Share(self, ent: StepBasic_Effectivity, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Effectivity) -> None: ...

class RWStepBasic_RWEffectivityAssignment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_EffectivityAssignment) -> None: ...
	def Share(self, ent: StepBasic_EffectivityAssignment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_EffectivityAssignment) -> None: ...

class RWStepBasic_RWEulerAngles:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_EulerAngles) -> None: ...
	def Share(self, ent: StepBasic_EulerAngles, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_EulerAngles) -> None: ...

class RWStepBasic_RWExternalIdentificationAssignment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ExternalIdentificationAssignment) -> None: ...
	def Share(self, ent: StepBasic_ExternalIdentificationAssignment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ExternalIdentificationAssignment) -> None: ...

class RWStepBasic_RWExternalSource:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ExternalSource) -> None: ...
	def Share(self, ent: StepBasic_ExternalSource, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ExternalSource) -> None: ...

class RWStepBasic_RWExternallyDefinedItem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ExternallyDefinedItem) -> None: ...
	def Share(self, ent: StepBasic_ExternallyDefinedItem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ExternallyDefinedItem) -> None: ...

class RWStepBasic_RWGeneralProperty:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_GeneralProperty) -> None: ...
	def Share(self, ent: StepBasic_GeneralProperty, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_GeneralProperty) -> None: ...

class RWStepBasic_RWGroup:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Group) -> None: ...
	def Share(self, ent: StepBasic_Group, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Group) -> None: ...

class RWStepBasic_RWGroupAssignment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_GroupAssignment) -> None: ...
	def Share(self, ent: StepBasic_GroupAssignment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_GroupAssignment) -> None: ...

class RWStepBasic_RWGroupRelationship:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_GroupRelationship) -> None: ...
	def Share(self, ent: StepBasic_GroupRelationship, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_GroupRelationship) -> None: ...

class RWStepBasic_RWIdentificationAssignment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_IdentificationAssignment) -> None: ...
	def Share(self, ent: StepBasic_IdentificationAssignment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_IdentificationAssignment) -> None: ...

class RWStepBasic_RWIdentificationRole:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_IdentificationRole) -> None: ...
	def Share(self, ent: StepBasic_IdentificationRole, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_IdentificationRole) -> None: ...

class RWStepBasic_RWLengthMeasureWithUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_LengthMeasureWithUnit) -> None: ...
	def Share(self, ent: StepBasic_LengthMeasureWithUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_LengthMeasureWithUnit) -> None: ...

class RWStepBasic_RWLengthUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_LengthUnit) -> None: ...
	def Share(self, ent: StepBasic_LengthUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_LengthUnit) -> None: ...

class RWStepBasic_RWLocalTime:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_LocalTime) -> None: ...
	def Share(self, ent: StepBasic_LocalTime, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_LocalTime) -> None: ...

class RWStepBasic_RWMassMeasureWithUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_MassMeasureWithUnit) -> None: ...
	def Share(self, ent: StepBasic_MassMeasureWithUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_MassMeasureWithUnit) -> None: ...

class RWStepBasic_RWMassUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_MassUnit) -> None: ...
	def Share(self, ent: StepBasic_MassUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_MassUnit) -> None: ...

class RWStepBasic_RWMeasureWithUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_MeasureWithUnit) -> None: ...
	def Share(self, ent: StepBasic_MeasureWithUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_MeasureWithUnit) -> None: ...

class RWStepBasic_RWMechanicalContext:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_MechanicalContext) -> None: ...
	def Share(self, ent: StepBasic_MechanicalContext, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_MechanicalContext) -> None: ...

class RWStepBasic_RWNameAssignment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_NameAssignment) -> None: ...
	def Share(self, ent: StepBasic_NameAssignment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_NameAssignment) -> None: ...

class RWStepBasic_RWNamedUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_NamedUnit) -> None: ...
	def Share(self, ent: StepBasic_NamedUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_NamedUnit) -> None: ...

class RWStepBasic_RWObjectRole:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ObjectRole) -> None: ...
	def Share(self, ent: StepBasic_ObjectRole, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ObjectRole) -> None: ...

class RWStepBasic_RWOrdinalDate:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_OrdinalDate) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_OrdinalDate) -> None: ...

class RWStepBasic_RWOrganization:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Organization) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Organization) -> None: ...

class RWStepBasic_RWOrganizationRole:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_OrganizationRole) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_OrganizationRole) -> None: ...

class RWStepBasic_RWOrganizationalAddress:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_OrganizationalAddress) -> None: ...
	def Share(self, ent: StepBasic_OrganizationalAddress, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_OrganizationalAddress) -> None: ...

class RWStepBasic_RWPerson:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Person) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Person) -> None: ...

class RWStepBasic_RWPersonAndOrganization:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_PersonAndOrganization) -> None: ...
	def Share(self, ent: StepBasic_PersonAndOrganization, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_PersonAndOrganization) -> None: ...

class RWStepBasic_RWPersonAndOrganizationRole:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_PersonAndOrganizationRole) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_PersonAndOrganizationRole) -> None: ...

class RWStepBasic_RWPersonalAddress:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_PersonalAddress) -> None: ...
	def Share(self, ent: StepBasic_PersonalAddress, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_PersonalAddress) -> None: ...

class RWStepBasic_RWPlaneAngleMeasureWithUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_PlaneAngleMeasureWithUnit) -> None: ...
	def Share(self, ent: StepBasic_PlaneAngleMeasureWithUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_PlaneAngleMeasureWithUnit) -> None: ...

class RWStepBasic_RWPlaneAngleUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_PlaneAngleUnit) -> None: ...
	def Share(self, ent: StepBasic_PlaneAngleUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_PlaneAngleUnit) -> None: ...

class RWStepBasic_RWProduct:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_Product) -> None: ...
	def Share(self, ent: StepBasic_Product, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_Product) -> None: ...

class RWStepBasic_RWProductCategory:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductCategory) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductCategory) -> None: ...

class RWStepBasic_RWProductCategoryRelationship:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductCategoryRelationship) -> None: ...
	def Share(self, ent: StepBasic_ProductCategoryRelationship, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductCategoryRelationship) -> None: ...

class RWStepBasic_RWProductConceptContext:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductConceptContext) -> None: ...
	def Share(self, ent: StepBasic_ProductConceptContext, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductConceptContext) -> None: ...

class RWStepBasic_RWProductContext:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductContext) -> None: ...
	def Share(self, ent: StepBasic_ProductContext, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductContext) -> None: ...

class RWStepBasic_RWProductDefinition:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductDefinition) -> None: ...
	def Share(self, ent: StepBasic_ProductDefinition, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductDefinition) -> None: ...

class RWStepBasic_RWProductDefinitionContext:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductDefinitionContext) -> None: ...
	def Share(self, ent: StepBasic_ProductDefinitionContext, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductDefinitionContext) -> None: ...

class RWStepBasic_RWProductDefinitionEffectivity:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductDefinitionEffectivity) -> None: ...
	def Share(self, ent: StepBasic_ProductDefinitionEffectivity, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductDefinitionEffectivity) -> None: ...

class RWStepBasic_RWProductDefinitionFormation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductDefinitionFormation) -> None: ...
	def Share(self, ent: StepBasic_ProductDefinitionFormation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductDefinitionFormation) -> None: ...

class RWStepBasic_RWProductDefinitionFormationRelationship:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductDefinitionFormationRelationship) -> None: ...
	def Share(self, ent: StepBasic_ProductDefinitionFormationRelationship, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductDefinitionFormationRelationship) -> None: ...

class RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductDefinitionFormationWithSpecifiedSource) -> None: ...
	def Share(self, ent: StepBasic_ProductDefinitionFormationWithSpecifiedSource, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductDefinitionFormationWithSpecifiedSource) -> None: ...

class RWStepBasic_RWProductDefinitionReference:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductDefinitionReference) -> None: ...
	def Share(self, ent: StepBasic_ProductDefinitionReference, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductDefinitionReference) -> None: ...

class RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductDefinitionReferenceWithLocalRepresentation) -> None: ...
	def Share(self, ent: StepBasic_ProductDefinitionReferenceWithLocalRepresentation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductDefinitionReferenceWithLocalRepresentation) -> None: ...

class RWStepBasic_RWProductDefinitionRelationship:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductDefinitionRelationship) -> None: ...
	def Share(self, ent: StepBasic_ProductDefinitionRelationship, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductDefinitionRelationship) -> None: ...

class RWStepBasic_RWProductDefinitionWithAssociatedDocuments:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductDefinitionWithAssociatedDocuments) -> None: ...
	def Share(self, ent: StepBasic_ProductDefinitionWithAssociatedDocuments, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductDefinitionWithAssociatedDocuments) -> None: ...

class RWStepBasic_RWProductRelatedProductCategory:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductRelatedProductCategory) -> None: ...
	def Share(self, ent: StepBasic_ProductRelatedProductCategory, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductRelatedProductCategory) -> None: ...

class RWStepBasic_RWProductType:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ProductType) -> None: ...
	def Share(self, ent: StepBasic_ProductType, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ProductType) -> None: ...

class RWStepBasic_RWRatioMeasureWithUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_RatioMeasureWithUnit) -> None: ...
	def Share(self, ent: StepBasic_RatioMeasureWithUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_RatioMeasureWithUnit) -> None: ...

class RWStepBasic_RWRoleAssociation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_RoleAssociation) -> None: ...
	def Share(self, ent: StepBasic_RoleAssociation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_RoleAssociation) -> None: ...

class RWStepBasic_RWSecurityClassification:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SecurityClassification) -> None: ...
	def Share(self, ent: StepBasic_SecurityClassification, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SecurityClassification) -> None: ...

class RWStepBasic_RWSecurityClassificationLevel:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SecurityClassificationLevel) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SecurityClassificationLevel) -> None: ...

class RWStepBasic_RWSiUnit:
	def __init__(self) -> None: ...
	def DecodeName(self, aName: StepBasic_SiUnitName, text: str) -> bool: ...
	def DecodePrefix(self, aPrefix: StepBasic_SiPrefix, text: str) -> bool: ...
	def EncodeName(self, aName: StepBasic_SiUnitName) -> TCollection_AsciiString: ...
	def EncodePrefix(self, aPrefix: StepBasic_SiPrefix) -> TCollection_AsciiString: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SiUnit) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SiUnit) -> None: ...

class RWStepBasic_RWSiUnitAndAreaUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SiUnitAndAreaUnit) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SiUnitAndAreaUnit) -> None: ...

class RWStepBasic_RWSiUnitAndLengthUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SiUnitAndLengthUnit) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SiUnitAndLengthUnit) -> None: ...

class RWStepBasic_RWSiUnitAndMassUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SiUnitAndMassUnit) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SiUnitAndMassUnit) -> None: ...

class RWStepBasic_RWSiUnitAndPlaneAngleUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SiUnitAndPlaneAngleUnit) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SiUnitAndPlaneAngleUnit) -> None: ...

class RWStepBasic_RWSiUnitAndRatioUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SiUnitAndRatioUnit) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SiUnitAndRatioUnit) -> None: ...

class RWStepBasic_RWSiUnitAndSolidAngleUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SiUnitAndSolidAngleUnit) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SiUnitAndSolidAngleUnit) -> None: ...

class RWStepBasic_RWSiUnitAndThermodynamicTemperatureUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SiUnitAndThermodynamicTemperatureUnit) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SiUnitAndThermodynamicTemperatureUnit) -> None: ...

class RWStepBasic_RWSiUnitAndTimeUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SiUnitAndTimeUnit) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SiUnitAndTimeUnit) -> None: ...

class RWStepBasic_RWSiUnitAndVolumeUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SiUnitAndVolumeUnit) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SiUnitAndVolumeUnit) -> None: ...

class RWStepBasic_RWSolidAngleMeasureWithUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SolidAngleMeasureWithUnit) -> None: ...
	def Share(self, ent: StepBasic_SolidAngleMeasureWithUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SolidAngleMeasureWithUnit) -> None: ...

class RWStepBasic_RWSolidAngleUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_SolidAngleUnit) -> None: ...
	def Share(self, ent: StepBasic_SolidAngleUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_SolidAngleUnit) -> None: ...

class RWStepBasic_RWThermodynamicTemperatureUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_ThermodynamicTemperatureUnit) -> None: ...
	def Share(self, ent: StepBasic_ThermodynamicTemperatureUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_ThermodynamicTemperatureUnit) -> None: ...

class RWStepBasic_RWUncertaintyMeasureWithUnit:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_UncertaintyMeasureWithUnit) -> None: ...
	def Share(self, ent: StepBasic_UncertaintyMeasureWithUnit, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_UncertaintyMeasureWithUnit) -> None: ...

class RWStepBasic_RWVersionedActionRequest:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_VersionedActionRequest) -> None: ...
	def Share(self, ent: StepBasic_VersionedActionRequest, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_VersionedActionRequest) -> None: ...

class RWStepBasic_RWWeekOfYearAndDayDate:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepBasic_WeekOfYearAndDayDate) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepBasic_WeekOfYearAndDayDate) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColStd import *
from OCC.Core.Geom2d import *
from OCC.Core.gp import *
from OCC.Core.MAT import *
from OCC.Core.Bisector import *

#the following typedef cannot be wrapped as is
MAT2d_Array2OfConnexion = NewType('MAT2d_Array2OfConnexion', Any)

class MAT2d_SequenceOfConnexion:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class MAT2d_SequenceOfSequenceOfCurve:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TColGeom2d_SequenceOfCurve: ...
    def Last(self) -> TColGeom2d_SequenceOfCurve: ...
    def Length(self) -> int: ...
    def Append(self, theItem: TColGeom2d_SequenceOfCurve) -> TColGeom2d_SequenceOfCurve: ...
    def Prepend(self, theItem: TColGeom2d_SequenceOfCurve) -> TColGeom2d_SequenceOfCurve: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TColGeom2d_SequenceOfCurve: ...
    def SetValue(self, theIndex: int, theValue: TColGeom2d_SequenceOfCurve) -> None: ...

class MAT2d_SequenceOfSequenceOfGeometry:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TColGeom2d_SequenceOfGeometry: ...
    def Last(self) -> TColGeom2d_SequenceOfGeometry: ...
    def Length(self) -> int: ...
    def Append(self, theItem: TColGeom2d_SequenceOfGeometry) -> TColGeom2d_SequenceOfGeometry: ...
    def Prepend(self, theItem: TColGeom2d_SequenceOfGeometry) -> TColGeom2d_SequenceOfGeometry: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TColGeom2d_SequenceOfGeometry: ...
    def SetValue(self, theIndex: int, theValue: TColGeom2d_SequenceOfGeometry) -> None: ...

class MAT2d_BiInt:
	def __init__(self, I1: int, I2: int) -> None: ...
	@overload
	def FirstIndex(self) -> int: ...
	@overload
	def FirstIndex(self, I1: int) -> None: ...
	def IsEqual(self, B: MAT2d_BiInt) -> bool: ...
	@overload
	def SecondIndex(self) -> int: ...
	@overload
	def SecondIndex(self, I2: int) -> None: ...

class MAT2d_Circuit(Standard_Transient):
	def __init__(self, aJoinType: Optional[GeomAbs_JoinType] = GeomAbs_Arc, IsOpenResult: Optional[bool] = False) -> None: ...
	def Connexion(self, Index: int) -> MAT2d_Connexion: ...
	def ConnexionOn(self, Index: int) -> bool: ...
	def LineLength(self, IndexLine: int) -> int: ...
	def NumberOfItems(self) -> int: ...
	def Perform(self, aFigure: MAT2d_SequenceOfSequenceOfGeometry, IsClosed: TColStd_SequenceOfBoolean, IndRefLine: int, Trigo: bool) -> None: ...
	def RefToEqui(self, IndLine: int, IndCurve: int) -> TColStd_SequenceOfInteger: ...
	def Value(self, Index: int) -> Geom2d_Geometry: ...

class MAT2d_Connexion(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, LineA: int, LineB: int, ItemA: int, ItemB: int, Distance: float, ParameterOnA: float, ParameterOnB: float, PointA: gp_Pnt2d, PointB: gp_Pnt2d) -> None: ...
	@overload
	def Distance(self) -> float: ...
	@overload
	def Distance(self, aDistance: float) -> None: ...
	def Dump(self, Deep: Optional[int] = 0, Offset: Optional[int] = 0) -> None: ...
	@overload
	def IndexFirstLine(self) -> int: ...
	@overload
	def IndexFirstLine(self, anIndex: int) -> None: ...
	@overload
	def IndexItemOnFirst(self) -> int: ...
	@overload
	def IndexItemOnFirst(self, anIndex: int) -> None: ...
	@overload
	def IndexItemOnSecond(self) -> int: ...
	@overload
	def IndexItemOnSecond(self, anIndex: int) -> None: ...
	@overload
	def IndexSecondLine(self) -> int: ...
	@overload
	def IndexSecondLine(self, anIndex: int) -> None: ...
	def IsAfter(self, aConnexion: MAT2d_Connexion, aSense: float) -> bool: ...
	@overload
	def ParameterOnFirst(self) -> float: ...
	@overload
	def ParameterOnFirst(self, aParameter: float) -> None: ...
	@overload
	def ParameterOnSecond(self) -> float: ...
	@overload
	def ParameterOnSecond(self, aParameter: float) -> None: ...
	@overload
	def PointOnFirst(self) -> gp_Pnt2d: ...
	@overload
	def PointOnFirst(self, aPoint: gp_Pnt2d) -> None: ...
	@overload
	def PointOnSecond(self) -> gp_Pnt2d: ...
	@overload
	def PointOnSecond(self, aPoint: gp_Pnt2d) -> None: ...
	def Reverse(self) -> MAT2d_Connexion: ...

class MAT2d_MapBiIntHasher:
	@staticmethod
	def HashCode(theKey: MAT2d_BiInt, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(Key1: MAT2d_BiInt, Key2: MAT2d_BiInt) -> bool: ...

class MAT2d_Mat2d:
	def __init__(self, IsOpenResult: Optional[bool] = False) -> None: ...
	def Bisector(self) -> MAT_Bisector: ...
	def CreateMat(self, aTool: MAT2d_Tool2d) -> None: ...
	def CreateMatOpen(self, aTool: MAT2d_Tool2d) -> None: ...
	def Init(self) -> None: ...
	def IsDone(self) -> bool: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def NumberOfBisectors(self) -> int: ...
	def SemiInfinite(self) -> bool: ...

class MAT2d_MiniPath:
	def __init__(self) -> None: ...
	def ConnexionsFrom(self, Index: int) -> MAT2d_SequenceOfConnexion: ...
	def Father(self, Index: int) -> MAT2d_Connexion: ...
	def IsConnexionsFrom(self, Index: int) -> bool: ...
	def IsRoot(self, Index: int) -> bool: ...
	def Path(self) -> MAT2d_SequenceOfConnexion: ...
	def Perform(self, Figure: MAT2d_SequenceOfSequenceOfGeometry, IndStart: int, Sense: bool) -> None: ...
	def RunOnConnexions(self) -> None: ...

class MAT2d_Tool2d:
	def __init__(self) -> None: ...
	def BisecFusion(self, Index1: int, Index2: int) -> None: ...
	def ChangeGeomBis(self, Index: int) -> Bisector_Bisec: ...
	def Circuit(self) -> MAT2d_Circuit: ...
	def CreateBisector(self, abisector: MAT_Bisector) -> None: ...
	def Distance(self, abisector: MAT_Bisector, param1: float, param2: float) -> float: ...
	def Dump(self, bisector: int, erease: int) -> None: ...
	def FirstPoint(self, anitem: int) -> Tuple[int, float]: ...
	def GeomBis(self, Index: int) -> Bisector_Bisec: ...
	def GeomElt(self, Index: int) -> Geom2d_Geometry: ...
	def GeomPnt(self, Index: int) -> gp_Pnt2d: ...
	def GeomVec(self, Index: int) -> gp_Vec2d: ...
	def InitItems(self, aCircuit: MAT2d_Circuit) -> None: ...
	def IntersectBisector(self, bisectorone: MAT_Bisector, bisectortwo: MAT_Bisector) -> Tuple[float, int]: ...
	def NumberOfItems(self) -> int: ...
	def Sense(self, aside: MAT_Side) -> None: ...
	def SetJoinType(self, aJoinType: GeomAbs_JoinType) -> None: ...
	def Tangent(self, bisector: int) -> int: ...
	def TangentAfter(self, anitem: int, IsOpenResult: bool) -> int: ...
	def TangentBefore(self, anitem: int, IsOpenResult: bool) -> int: ...
	def ToleranceOfConfusion(self) -> float: ...
	@overload
	def TrimBisector(self, abisector: MAT_Bisector) -> bool: ...
	@overload
	def TrimBisector(self, abisector: MAT_Bisector, apoint: int) -> bool: ...

#classnotwrapped
class MAT2d_SketchExplorer: ...

#classnotwrapped
class MAT2d_CutCurve: ...

# harray1 classes
# harray2 classes
# hsequence classes

MAT2d_MapBiIntHasher_HashCode = MAT2d_MapBiIntHasher.HashCode
MAT2d_MapBiIntHasher_IsEqual = MAT2d_MapBiIntHasher.IsEqual



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TCollection import *
from OCC.Core.StepRepr import *
from OCC.Core.StepData import *
from OCC.Core.TColStd import *

#the following typedef cannot be wrapped as is
StepElement_Array2OfCurveElementPurposeMember = NewType('StepElement_Array2OfCurveElementPurposeMember', Any)
#the following typedef cannot be wrapped as is
StepElement_Array2OfSurfaceElementPurpose = NewType('StepElement_Array2OfSurfaceElementPurpose', Any)
#the following typedef cannot be wrapped as is
StepElement_Array2OfSurfaceElementPurposeMember = NewType('StepElement_Array2OfSurfaceElementPurposeMember', Any)

class StepElement_Array1OfCurveElementEndReleasePacket:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepElement_Array1OfCurveElementSectionDefinition:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepElement_Array1OfHSequenceOfCurveElementPurposeMember:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepElement_Array1OfHSequenceOfSurfaceElementPurposeMember:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepElement_Array1OfMeasureOrUnspecifiedValue:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepElement_MeasureOrUnspecifiedValue: ...
    def __setitem__(self, index: int, value: StepElement_MeasureOrUnspecifiedValue) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepElement_MeasureOrUnspecifiedValue]: ...
    def next(self) -> StepElement_MeasureOrUnspecifiedValue: ...
    __next__ = next
    def Init(self, theValue: StepElement_MeasureOrUnspecifiedValue) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepElement_MeasureOrUnspecifiedValue: ...
    def Last(self) -> StepElement_MeasureOrUnspecifiedValue: ...
    def Value(self, theIndex: int) -> StepElement_MeasureOrUnspecifiedValue: ...
    def SetValue(self, theIndex: int, theValue: StepElement_MeasureOrUnspecifiedValue) -> None: ...

class StepElement_Array1OfSurfaceSection:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepElement_Array1OfVolumeElementPurpose:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepElement_VolumeElementPurpose: ...
    def __setitem__(self, index: int, value: StepElement_VolumeElementPurpose) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepElement_VolumeElementPurpose]: ...
    def next(self) -> StepElement_VolumeElementPurpose: ...
    __next__ = next
    def Init(self, theValue: StepElement_VolumeElementPurpose) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepElement_VolumeElementPurpose: ...
    def Last(self) -> StepElement_VolumeElementPurpose: ...
    def Value(self, theIndex: int) -> StepElement_VolumeElementPurpose: ...
    def SetValue(self, theIndex: int, theValue: StepElement_VolumeElementPurpose) -> None: ...

class StepElement_Array1OfVolumeElementPurposeMember:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepElement_SequenceOfCurveElementPurposeMember:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepElement_SequenceOfCurveElementSectionDefinition:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepElement_SequenceOfElementMaterial:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepElement_SequenceOfSurfaceElementPurposeMember:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepElement_ElementVolume(IntEnum):
	StepElement_Volume: int = ...
StepElement_Volume = StepElement_ElementVolume.StepElement_Volume

class StepElement_CurveEdge(IntEnum):
	StepElement_ElementEdge: int = ...
StepElement_ElementEdge = StepElement_CurveEdge.StepElement_ElementEdge

class StepElement_Volume3dElementShape(IntEnum):
	StepElement_Hexahedron: int = ...
	StepElement_Wedge: int = ...
	StepElement_Tetrahedron: int = ...
	StepElement_Pyramid: int = ...
StepElement_Hexahedron = StepElement_Volume3dElementShape.StepElement_Hexahedron
StepElement_Wedge = StepElement_Volume3dElementShape.StepElement_Wedge
StepElement_Tetrahedron = StepElement_Volume3dElementShape.StepElement_Tetrahedron
StepElement_Pyramid = StepElement_Volume3dElementShape.StepElement_Pyramid

class StepElement_ElementOrder(IntEnum):
	StepElement_Linear: int = ...
	StepElement_Quadratic: int = ...
	StepElement_Cubic: int = ...
StepElement_Linear = StepElement_ElementOrder.StepElement_Linear
StepElement_Quadratic = StepElement_ElementOrder.StepElement_Quadratic
StepElement_Cubic = StepElement_ElementOrder.StepElement_Cubic

class StepElement_Element2dShape(IntEnum):
	StepElement_Quadrilateral: int = ...
	StepElement_Triangle: int = ...
StepElement_Quadrilateral = StepElement_Element2dShape.StepElement_Quadrilateral
StepElement_Triangle = StepElement_Element2dShape.StepElement_Triangle

class StepElement_EnumeratedCurveElementFreedom(IntEnum):
	StepElement_XTranslation: int = ...
	StepElement_YTranslation: int = ...
	StepElement_ZTranslation: int = ...
	StepElement_XRotation: int = ...
	StepElement_YRotation: int = ...
	StepElement_ZRotation: int = ...
	StepElement_Warp: int = ...
	StepElement_None: int = ...
StepElement_XTranslation = StepElement_EnumeratedCurveElementFreedom.StepElement_XTranslation
StepElement_YTranslation = StepElement_EnumeratedCurveElementFreedom.StepElement_YTranslation
StepElement_ZTranslation = StepElement_EnumeratedCurveElementFreedom.StepElement_ZTranslation
StepElement_XRotation = StepElement_EnumeratedCurveElementFreedom.StepElement_XRotation
StepElement_YRotation = StepElement_EnumeratedCurveElementFreedom.StepElement_YRotation
StepElement_ZRotation = StepElement_EnumeratedCurveElementFreedom.StepElement_ZRotation
StepElement_Warp = StepElement_EnumeratedCurveElementFreedom.StepElement_Warp
StepElement_None = StepElement_EnumeratedCurveElementFreedom.StepElement_None

class StepElement_EnumeratedVolumeElementPurpose(IntEnum):
	StepElement_StressDisplacement: int = ...
StepElement_StressDisplacement = StepElement_EnumeratedVolumeElementPurpose.StepElement_StressDisplacement

class StepElement_EnumeratedSurfaceElementPurpose(IntEnum):
	StepElement_MembraneDirect: int = ...
	StepElement_MembraneShear: int = ...
	StepElement_BendingDirect: int = ...
	StepElement_BendingTorsion: int = ...
	StepElement_NormalToPlaneShear: int = ...
StepElement_MembraneDirect = StepElement_EnumeratedSurfaceElementPurpose.StepElement_MembraneDirect
StepElement_MembraneShear = StepElement_EnumeratedSurfaceElementPurpose.StepElement_MembraneShear
StepElement_BendingDirect = StepElement_EnumeratedSurfaceElementPurpose.StepElement_BendingDirect
StepElement_BendingTorsion = StepElement_EnumeratedSurfaceElementPurpose.StepElement_BendingTorsion
StepElement_NormalToPlaneShear = StepElement_EnumeratedSurfaceElementPurpose.StepElement_NormalToPlaneShear

class StepElement_UnspecifiedValue(IntEnum):
	StepElement_Unspecified: int = ...
StepElement_Unspecified = StepElement_UnspecifiedValue.StepElement_Unspecified

class StepElement_EnumeratedCurveElementPurpose(IntEnum):
	StepElement_Axial: int = ...
	StepElement_YYBending: int = ...
	StepElement_ZZBending: int = ...
	StepElement_Torsion: int = ...
	StepElement_XYShear: int = ...
	StepElement_XZShear: int = ...
	StepElement_Warping: int = ...
StepElement_Axial = StepElement_EnumeratedCurveElementPurpose.StepElement_Axial
StepElement_YYBending = StepElement_EnumeratedCurveElementPurpose.StepElement_YYBending
StepElement_ZZBending = StepElement_EnumeratedCurveElementPurpose.StepElement_ZZBending
StepElement_Torsion = StepElement_EnumeratedCurveElementPurpose.StepElement_Torsion
StepElement_XYShear = StepElement_EnumeratedCurveElementPurpose.StepElement_XYShear
StepElement_XZShear = StepElement_EnumeratedCurveElementPurpose.StepElement_XZShear
StepElement_Warping = StepElement_EnumeratedCurveElementPurpose.StepElement_Warping

class StepElement_AnalysisItemWithinRepresentation(Standard_Transient):
	def __init__(self) -> None: ...
	def Description(self) -> TCollection_HAsciiString: ...
	def Init(self, aName: TCollection_HAsciiString, aDescription: TCollection_HAsciiString, aItem: StepRepr_RepresentationItem, aRep: StepRepr_Representation) -> None: ...
	def Item(self) -> StepRepr_RepresentationItem: ...
	def Name(self) -> TCollection_HAsciiString: ...
	def Rep(self) -> StepRepr_Representation: ...
	def SetDescription(self, Description: TCollection_HAsciiString) -> None: ...
	def SetItem(self, Item: StepRepr_RepresentationItem) -> None: ...
	def SetName(self, Name: TCollection_HAsciiString) -> None: ...
	def SetRep(self, Rep: StepRepr_Representation) -> None: ...

class StepElement_CurveElementEndReleasePacket(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, aReleaseFreedom: StepElement_CurveElementFreedom, aReleaseStiffness: float) -> None: ...
	def ReleaseFreedom(self) -> StepElement_CurveElementFreedom: ...
	def ReleaseStiffness(self) -> float: ...
	def SetReleaseFreedom(self, ReleaseFreedom: StepElement_CurveElementFreedom) -> None: ...
	def SetReleaseStiffness(self, ReleaseStiffness: float) -> None: ...

class StepElement_CurveElementFreedom(StepData_SelectType):
	def __init__(self) -> None: ...
	def ApplicationDefinedDegreeOfFreedom(self) -> TCollection_HAsciiString: ...
	def CaseMem(self, ent: StepData_SelectMember) -> int: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def EnumeratedCurveElementFreedom(self) -> StepElement_EnumeratedCurveElementFreedom: ...
	def NewMember(self) -> StepData_SelectMember: ...
	def SetApplicationDefinedDegreeOfFreedom(self, aVal: TCollection_HAsciiString) -> None: ...
	def SetEnumeratedCurveElementFreedom(self, aVal: StepElement_EnumeratedCurveElementFreedom) -> None: ...

class StepElement_CurveElementFreedomMember(StepData_SelectNamed):
	def __init__(self) -> None: ...
	def HasName(self) -> bool: ...
	def Matches(self, name: str) -> bool: ...
	def Name(self) -> str: ...
	def SetName(self, name: str) -> bool: ...

class StepElement_CurveElementPurpose(StepData_SelectType):
	def __init__(self) -> None: ...
	def ApplicationDefinedElementPurpose(self) -> TCollection_HAsciiString: ...
	def CaseMem(self, ent: StepData_SelectMember) -> int: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def EnumeratedCurveElementPurpose(self) -> StepElement_EnumeratedCurveElementPurpose: ...
	def NewMember(self) -> StepData_SelectMember: ...
	def SetApplicationDefinedElementPurpose(self, aVal: TCollection_HAsciiString) -> None: ...
	def SetEnumeratedCurveElementPurpose(self, aVal: StepElement_EnumeratedCurveElementPurpose) -> None: ...

class StepElement_CurveElementPurposeMember(StepData_SelectNamed):
	def __init__(self) -> None: ...
	def HasName(self) -> bool: ...
	def Matches(self, name: str) -> bool: ...
	def Name(self) -> str: ...
	def SetName(self, name: str) -> bool: ...

class StepElement_CurveElementSectionDefinition(Standard_Transient):
	def __init__(self) -> None: ...
	def Description(self) -> TCollection_HAsciiString: ...
	def Init(self, aDescription: TCollection_HAsciiString, aSectionAngle: float) -> None: ...
	def SectionAngle(self) -> float: ...
	def SetDescription(self, Description: TCollection_HAsciiString) -> None: ...
	def SetSectionAngle(self, SectionAngle: float) -> None: ...

class StepElement_ElementAspect(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseMem(self, ent: StepData_SelectMember) -> int: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def CurveEdge(self) -> StepElement_CurveEdge: ...
	def ElementVolume(self) -> StepElement_ElementVolume: ...
	def NewMember(self) -> StepData_SelectMember: ...
	def SetCurveEdge(self, aVal: StepElement_CurveEdge) -> None: ...
	def SetElementVolume(self, aVal: StepElement_ElementVolume) -> None: ...
	def SetSurface2dEdge(self, aVal: int) -> None: ...
	def SetSurface2dFace(self, aVal: int) -> None: ...
	def SetSurface3dEdge(self, aVal: int) -> None: ...
	def SetSurface3dFace(self, aVal: int) -> None: ...
	def SetVolume2dEdge(self, aVal: int) -> None: ...
	def SetVolume2dFace(self, aVal: int) -> None: ...
	def SetVolume3dEdge(self, aVal: int) -> None: ...
	def SetVolume3dFace(self, aVal: int) -> None: ...
	def Surface2dEdge(self) -> int: ...
	def Surface2dFace(self) -> int: ...
	def Surface3dEdge(self) -> int: ...
	def Surface3dFace(self) -> int: ...
	def Volume2dEdge(self) -> int: ...
	def Volume2dFace(self) -> int: ...
	def Volume3dEdge(self) -> int: ...
	def Volume3dFace(self) -> int: ...

class StepElement_ElementAspectMember(StepData_SelectNamed):
	def __init__(self) -> None: ...
	def HasName(self) -> bool: ...
	def Matches(self, name: str) -> bool: ...
	def Name(self) -> str: ...
	def SetName(self, name: str) -> bool: ...

class StepElement_ElementDescriptor(Standard_Transient):
	def __init__(self) -> None: ...
	def Description(self) -> TCollection_HAsciiString: ...
	def Init(self, aTopologyOrder: StepElement_ElementOrder, aDescription: TCollection_HAsciiString) -> None: ...
	def SetDescription(self, Description: TCollection_HAsciiString) -> None: ...
	def SetTopologyOrder(self, TopologyOrder: StepElement_ElementOrder) -> None: ...
	def TopologyOrder(self) -> StepElement_ElementOrder: ...

class StepElement_ElementMaterial(Standard_Transient):
	def __init__(self) -> None: ...
	def Description(self) -> TCollection_HAsciiString: ...
	def Init(self, aMaterialId: TCollection_HAsciiString, aDescription: TCollection_HAsciiString, aProperties: StepRepr_HArray1OfMaterialPropertyRepresentation) -> None: ...
	def MaterialId(self) -> TCollection_HAsciiString: ...
	def Properties(self) -> StepRepr_HArray1OfMaterialPropertyRepresentation: ...
	def SetDescription(self, Description: TCollection_HAsciiString) -> None: ...
	def SetMaterialId(self, MaterialId: TCollection_HAsciiString) -> None: ...
	def SetProperties(self, Properties: StepRepr_HArray1OfMaterialPropertyRepresentation) -> None: ...

class StepElement_MeasureOrUnspecifiedValue(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseMem(self, ent: StepData_SelectMember) -> int: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ContextDependentMeasure(self) -> float: ...
	def NewMember(self) -> StepData_SelectMember: ...
	def SetContextDependentMeasure(self, aVal: float) -> None: ...
	def SetUnspecifiedValue(self, aVal: StepElement_UnspecifiedValue) -> None: ...
	def UnspecifiedValue(self) -> StepElement_UnspecifiedValue: ...

class StepElement_MeasureOrUnspecifiedValueMember(StepData_SelectNamed):
	def __init__(self) -> None: ...
	def HasName(self) -> bool: ...
	def Matches(self, name: str) -> bool: ...
	def Name(self) -> str: ...
	def SetName(self, name: str) -> bool: ...

class StepElement_SurfaceElementProperty(Standard_Transient):
	def __init__(self) -> None: ...
	def Description(self) -> TCollection_HAsciiString: ...
	def Init(self, aPropertyId: TCollection_HAsciiString, aDescription: TCollection_HAsciiString, aSection: StepElement_SurfaceSectionField) -> None: ...
	def PropertyId(self) -> TCollection_HAsciiString: ...
	def Section(self) -> StepElement_SurfaceSectionField: ...
	def SetDescription(self, Description: TCollection_HAsciiString) -> None: ...
	def SetPropertyId(self, PropertyId: TCollection_HAsciiString) -> None: ...
	def SetSection(self, Section: StepElement_SurfaceSectionField) -> None: ...

class StepElement_SurfaceElementPurpose(StepData_SelectType):
	def __init__(self) -> None: ...
	def ApplicationDefinedElementPurpose(self) -> TCollection_HAsciiString: ...
	def CaseMem(self, ent: StepData_SelectMember) -> int: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def EnumeratedSurfaceElementPurpose(self) -> StepElement_EnumeratedSurfaceElementPurpose: ...
	def NewMember(self) -> StepData_SelectMember: ...
	def SetApplicationDefinedElementPurpose(self, aVal: TCollection_HAsciiString) -> None: ...
	def SetEnumeratedSurfaceElementPurpose(self, aVal: StepElement_EnumeratedSurfaceElementPurpose) -> None: ...

class StepElement_SurfaceElementPurposeMember(StepData_SelectNamed):
	def __init__(self) -> None: ...
	def HasName(self) -> bool: ...
	def Matches(self, name: str) -> bool: ...
	def Name(self) -> str: ...
	def SetName(self, name: str) -> bool: ...

class StepElement_SurfaceSection(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, aOffset: StepElement_MeasureOrUnspecifiedValue, aNonStructuralMass: StepElement_MeasureOrUnspecifiedValue, aNonStructuralMassOffset: StepElement_MeasureOrUnspecifiedValue) -> None: ...
	def NonStructuralMass(self) -> StepElement_MeasureOrUnspecifiedValue: ...
	def NonStructuralMassOffset(self) -> StepElement_MeasureOrUnspecifiedValue: ...
	def Offset(self) -> StepElement_MeasureOrUnspecifiedValue: ...
	def SetNonStructuralMass(self, NonStructuralMass: StepElement_MeasureOrUnspecifiedValue) -> None: ...
	def SetNonStructuralMassOffset(self, NonStructuralMassOffset: StepElement_MeasureOrUnspecifiedValue) -> None: ...
	def SetOffset(self, Offset: StepElement_MeasureOrUnspecifiedValue) -> None: ...

class StepElement_SurfaceSectionField(Standard_Transient):
	def __init__(self) -> None: ...

class StepElement_VolumeElementPurpose(StepData_SelectType):
	def __init__(self) -> None: ...
	def ApplicationDefinedElementPurpose(self) -> TCollection_HAsciiString: ...
	def CaseMem(self, ent: StepData_SelectMember) -> int: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def EnumeratedVolumeElementPurpose(self) -> StepElement_EnumeratedVolumeElementPurpose: ...
	def NewMember(self) -> StepData_SelectMember: ...
	def SetApplicationDefinedElementPurpose(self, aVal: TCollection_HAsciiString) -> None: ...
	def SetEnumeratedVolumeElementPurpose(self, aVal: StepElement_EnumeratedVolumeElementPurpose) -> None: ...

class StepElement_VolumeElementPurposeMember(StepData_SelectNamed):
	def __init__(self) -> None: ...
	def HasName(self) -> bool: ...
	def Matches(self, name: str) -> bool: ...
	def Name(self) -> str: ...
	def SetName(self, name: str) -> bool: ...

class StepElement_Curve3dElementDescriptor(StepElement_ElementDescriptor):
	def __init__(self) -> None: ...
	def Init(self, aElementDescriptor_TopologyOrder: StepElement_ElementOrder, aElementDescriptor_Description: TCollection_HAsciiString, aPurpose: StepElement_HArray1OfHSequenceOfCurveElementPurposeMember) -> None: ...
	def Purpose(self) -> StepElement_HArray1OfHSequenceOfCurveElementPurposeMember: ...
	def SetPurpose(self, Purpose: StepElement_HArray1OfHSequenceOfCurveElementPurposeMember) -> None: ...

class StepElement_CurveElementSectionDerivedDefinitions(StepElement_CurveElementSectionDefinition):
	def __init__(self) -> None: ...
	def CrossSectionalArea(self) -> float: ...
	def Init(self, aCurveElementSectionDefinition_Description: TCollection_HAsciiString, aCurveElementSectionDefinition_SectionAngle: float, aCrossSectionalArea: float, aShearArea: StepElement_HArray1OfMeasureOrUnspecifiedValue, aSecondMomentOfArea: TColStd_HArray1OfReal, aTorsionalConstant: float, aWarpingConstant: StepElement_MeasureOrUnspecifiedValue, aLocationOfCentroid: StepElement_HArray1OfMeasureOrUnspecifiedValue, aLocationOfShearCentre: StepElement_HArray1OfMeasureOrUnspecifiedValue, aLocationOfNonStructuralMass: StepElement_HArray1OfMeasureOrUnspecifiedValue, aNonStructuralMass: StepElement_MeasureOrUnspecifiedValue, aPolarMoment: StepElement_MeasureOrUnspecifiedValue) -> None: ...
	def LocationOfCentroid(self) -> StepElement_HArray1OfMeasureOrUnspecifiedValue: ...
	def LocationOfNonStructuralMass(self) -> StepElement_HArray1OfMeasureOrUnspecifiedValue: ...
	def LocationOfShearCentre(self) -> StepElement_HArray1OfMeasureOrUnspecifiedValue: ...
	def NonStructuralMass(self) -> StepElement_MeasureOrUnspecifiedValue: ...
	def PolarMoment(self) -> StepElement_MeasureOrUnspecifiedValue: ...
	def SecondMomentOfArea(self) -> TColStd_HArray1OfReal: ...
	def SetCrossSectionalArea(self, CrossSectionalArea: float) -> None: ...
	def SetLocationOfCentroid(self, LocationOfCentroid: StepElement_HArray1OfMeasureOrUnspecifiedValue) -> None: ...
	def SetLocationOfNonStructuralMass(self, LocationOfNonStructuralMass: StepElement_HArray1OfMeasureOrUnspecifiedValue) -> None: ...
	def SetLocationOfShearCentre(self, LocationOfShearCentre: StepElement_HArray1OfMeasureOrUnspecifiedValue) -> None: ...
	def SetNonStructuralMass(self, NonStructuralMass: StepElement_MeasureOrUnspecifiedValue) -> None: ...
	def SetPolarMoment(self, PolarMoment: StepElement_MeasureOrUnspecifiedValue) -> None: ...
	def SetSecondMomentOfArea(self, SecondMomentOfArea: TColStd_HArray1OfReal) -> None: ...
	def SetShearArea(self, ShearArea: StepElement_HArray1OfMeasureOrUnspecifiedValue) -> None: ...
	def SetTorsionalConstant(self, TorsionalConstant: float) -> None: ...
	def SetWarpingConstant(self, WarpingConstant: StepElement_MeasureOrUnspecifiedValue) -> None: ...
	def ShearArea(self) -> StepElement_HArray1OfMeasureOrUnspecifiedValue: ...
	def TorsionalConstant(self) -> float: ...
	def WarpingConstant(self) -> StepElement_MeasureOrUnspecifiedValue: ...

class StepElement_Surface3dElementDescriptor(StepElement_ElementDescriptor):
	def __init__(self) -> None: ...
	def Init(self, aElementDescriptor_TopologyOrder: StepElement_ElementOrder, aElementDescriptor_Description: TCollection_HAsciiString, aPurpose: StepElement_HArray1OfHSequenceOfSurfaceElementPurposeMember, aShape: StepElement_Element2dShape) -> None: ...
	def Purpose(self) -> StepElement_HArray1OfHSequenceOfSurfaceElementPurposeMember: ...
	def SetPurpose(self, Purpose: StepElement_HArray1OfHSequenceOfSurfaceElementPurposeMember) -> None: ...
	def SetShape(self, Shape: StepElement_Element2dShape) -> None: ...
	def Shape(self) -> StepElement_Element2dShape: ...

class StepElement_SurfaceSectionFieldConstant(StepElement_SurfaceSectionField):
	def __init__(self) -> None: ...
	def Definition(self) -> StepElement_SurfaceSection: ...
	def Init(self, aDefinition: StepElement_SurfaceSection) -> None: ...
	def SetDefinition(self, Definition: StepElement_SurfaceSection) -> None: ...

class StepElement_SurfaceSectionFieldVarying(StepElement_SurfaceSectionField):
	def __init__(self) -> None: ...
	def AdditionalNodeValues(self) -> bool: ...
	def Definitions(self) -> StepElement_HArray1OfSurfaceSection: ...
	def Init(self, aDefinitions: StepElement_HArray1OfSurfaceSection, aAdditionalNodeValues: bool) -> None: ...
	def SetAdditionalNodeValues(self, AdditionalNodeValues: bool) -> None: ...
	def SetDefinitions(self, Definitions: StepElement_HArray1OfSurfaceSection) -> None: ...

class StepElement_UniformSurfaceSection(StepElement_SurfaceSection):
	def __init__(self) -> None: ...
	def BendingThickness(self) -> StepElement_MeasureOrUnspecifiedValue: ...
	def Init(self, aSurfaceSection_Offset: StepElement_MeasureOrUnspecifiedValue, aSurfaceSection_NonStructuralMass: StepElement_MeasureOrUnspecifiedValue, aSurfaceSection_NonStructuralMassOffset: StepElement_MeasureOrUnspecifiedValue, aThickness: float, aBendingThickness: StepElement_MeasureOrUnspecifiedValue, aShearThickness: StepElement_MeasureOrUnspecifiedValue) -> None: ...
	def SetBendingThickness(self, BendingThickness: StepElement_MeasureOrUnspecifiedValue) -> None: ...
	def SetShearThickness(self, ShearThickness: StepElement_MeasureOrUnspecifiedValue) -> None: ...
	def SetThickness(self, Thickness: float) -> None: ...
	def ShearThickness(self) -> StepElement_MeasureOrUnspecifiedValue: ...
	def Thickness(self) -> float: ...

class StepElement_Volume3dElementDescriptor(StepElement_ElementDescriptor):
	def __init__(self) -> None: ...
	def Init(self, aElementDescriptor_TopologyOrder: StepElement_ElementOrder, aElementDescriptor_Description: TCollection_HAsciiString, aPurpose: StepElement_HArray1OfVolumeElementPurposeMember, aShape: StepElement_Volume3dElementShape) -> None: ...
	def Purpose(self) -> StepElement_HArray1OfVolumeElementPurposeMember: ...
	def SetPurpose(self, Purpose: StepElement_HArray1OfVolumeElementPurposeMember) -> None: ...
	def SetShape(self, Shape: StepElement_Volume3dElementShape) -> None: ...
	def Shape(self) -> StepElement_Volume3dElementShape: ...

# harray1 classes

class StepElement_HArray1OfVolumeElementPurpose(StepElement_Array1OfVolumeElementPurpose, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepElement_Array1OfVolumeElementPurpose: ...


class StepElement_HArray1OfHSequenceOfCurveElementPurposeMember(StepElement_Array1OfHSequenceOfCurveElementPurposeMember, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepElement_Array1OfHSequenceOfCurveElementPurposeMember: ...


class StepElement_HArray1OfSurfaceSection(StepElement_Array1OfSurfaceSection, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepElement_Array1OfSurfaceSection: ...


class StepElement_HArray1OfCurveElementSectionDefinition(StepElement_Array1OfCurveElementSectionDefinition, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepElement_Array1OfCurveElementSectionDefinition: ...


class StepElement_HArray1OfMeasureOrUnspecifiedValue(StepElement_Array1OfMeasureOrUnspecifiedValue, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepElement_Array1OfMeasureOrUnspecifiedValue: ...


class StepElement_HArray1OfHSequenceOfSurfaceElementPurposeMember(StepElement_Array1OfHSequenceOfSurfaceElementPurposeMember, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepElement_Array1OfHSequenceOfSurfaceElementPurposeMember: ...


class StepElement_HArray1OfVolumeElementPurposeMember(StepElement_Array1OfVolumeElementPurposeMember, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepElement_Array1OfVolumeElementPurposeMember: ...


class StepElement_HArray1OfCurveElementEndReleasePacket(StepElement_Array1OfCurveElementEndReleasePacket, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepElement_Array1OfCurveElementEndReleasePacket: ...

# harray2 classes

class StepElement_HArray2OfSurfaceElementPurposeMember(StepElement_Array2OfSurfaceElementPurposeMember, Standard_Transient):
    @overload
    def __init__(self, theRowLow: int, theRowUpp: int, theColLow: int, theColUpp: int) -> None: ...
    @overload
    def __init__(self, theOther: StepElement_Array2OfSurfaceElementPurposeMember) -> None: ...
    def Array2(self) -> StepElement_Array2OfSurfaceElementPurposeMember: ...


class StepElement_HArray2OfSurfaceElementPurpose(StepElement_Array2OfSurfaceElementPurpose, Standard_Transient):
    @overload
    def __init__(self, theRowLow: int, theRowUpp: int, theColLow: int, theColUpp: int) -> None: ...
    @overload
    def __init__(self, theOther: StepElement_Array2OfSurfaceElementPurpose) -> None: ...
    def Array2(self) -> StepElement_Array2OfSurfaceElementPurpose: ...


class StepElement_HArray2OfCurveElementPurposeMember(StepElement_Array2OfCurveElementPurposeMember, Standard_Transient):
    @overload
    def __init__(self, theRowLow: int, theRowUpp: int, theColLow: int, theColUpp: int) -> None: ...
    @overload
    def __init__(self, theOther: StepElement_Array2OfCurveElementPurposeMember) -> None: ...
    def Array2(self) -> StepElement_Array2OfCurveElementPurposeMember: ...

# hsequence classes

class StepElement_HSequenceOfCurveElementSectionDefinition(StepElement_SequenceOfCurveElementSectionDefinition, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: StepElement_SequenceOfCurveElementSectionDefinition) -> None: ...
    def Sequence(self) -> StepElement_SequenceOfCurveElementSectionDefinition: ...
    def Append(self, theSequence: StepElement_SequenceOfCurveElementSectionDefinition) -> None: ...


class StepElement_HSequenceOfCurveElementPurposeMember(StepElement_SequenceOfCurveElementPurposeMember, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: StepElement_SequenceOfCurveElementPurposeMember) -> None: ...
    def Sequence(self) -> StepElement_SequenceOfCurveElementPurposeMember: ...
    def Append(self, theSequence: StepElement_SequenceOfCurveElementPurposeMember) -> None: ...


class StepElement_HSequenceOfElementMaterial(StepElement_SequenceOfElementMaterial, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: StepElement_SequenceOfElementMaterial) -> None: ...
    def Sequence(self) -> StepElement_SequenceOfElementMaterial: ...
    def Append(self, theSequence: StepElement_SequenceOfElementMaterial) -> None: ...


class StepElement_HSequenceOfSurfaceElementPurposeMember(StepElement_SequenceOfSurfaceElementPurposeMember, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: StepElement_SequenceOfSurfaceElementPurposeMember) -> None: ...
    def Sequence(self) -> StepElement_SequenceOfSurfaceElementPurposeMember: ...
    def Append(self, theSequence: StepElement_SequenceOfSurfaceElementPurposeMember) -> None: ...


